
# Storage operation disaggregator

A module to disaggregate energy storage operation by time scales.
The disaggregation only requires the charging and discharging power profiles and is agnostic with respect to electricity prices or other drivers.

# Example

Please consult the [example notebook](storedisagg/example/std_example.ipynb)



